@@ -5,10 +5,11 @@ IS_WIN=False if platform.system().find('Linux')>-1 else True
 NOW=datetime.datetime.now()
 NOW_TS=math.floor(NOW.timestamp())
 NOW=NOW.strftime('%Y-%m-%d %H:%M:%S')
+start_time=0
 def is_numeric(x):
 	try:float(x);return True
 	except:return False
-def now(x=None):#x=micro return microsecond;x=str return string;x is int means convert timestamp to string;x is sting means convert string to timestamp
+def now(x=None):#x=micro return microsecond;x='str' return string;x is int means convert timestamp to string;x is sting means convert string to timestamp
 	if not x:return int(datetime.datetime.now().timestamp())
 	elif x=='micro':return datetime.datetime.now().timestamp()
 	elif x=='str':return datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
@@ -78,6 +79,7 @@ def obj(obj=None,remote=False,name:str =None,expire:(str,int)=None):
 					return None
 			return pickle.dump(obj,open(path,'wb'))
 def encrypt(string,password=None):
+	if isinstance(string,bytes): string=string.decode('latin')
 	first_letter=string[0]
 	hl = hashlib.sha512()
 	hl.update(first_letter.encode('utf-8')if password is None else password.encode('utf-8'))
@@ -110,6 +112,11 @@ def decrypt(string,password=None):
 	if password is None:
 		decrypted=first_letter+decrypted[1:]
 	return decrypted
+def start():
+	global start_time
+	start_time=now('micro')
+def end():
+	print(now('micro')-start_time)
 class mysql(object):
 	conn=None
 	def __init__(self, host='127.0.0.1',**args):
@@ -126,16 +133,34 @@ class mysql(object):
 		self.conn = self.pymysql.connect(**self.connect_config)
 	def __getattr__(self,attr):
 		return getattr(self.conn,attr)
+	def _decide_type(self,value):
+		if isinstance(value,(int,float)):
+			pass
+		elif value is None:
+			value='NULL'
+		else:
+			value='"'+self.pymysql.converters.escape_string(value)+'"'
+		return value
 	def _split_dict(self,dicts,splitor=','):
 		string=''
-		for x in dicts:
-			if isinstance(dicts[x],(int,float)):
-				data=dicts[x]
-			elif dicts[x] is None:
-				data='NULL'
+		for field in dicts:
+			if isinstance(dicts[field],(list,tuple)):
+				operator= dicts[field][0].upper()
+				if 'IN' in operator:
+					value=''
+					for in_value in dicts[field][1]:
+						value+=f'{self._decide_type(in_value)},'
+					value=value[:-1]
+					string+=f' `{field}` {operator} ({value}) {splitor}'
+				elif 'BETWEEN' in operator:
+					value=[self._decide_type(dicts[field][1][0]),self._decide_type(dicts[field][1][1])]
+					string+=f' `{field}` {operator} {value[0]} and {value[1]} {splitor}'
+				else:
+					value=self._decide_type(dicts[field][1])
+					string+=f' `{field}` {operator} {value} {splitor}'
 			else:
-				data='"'+self.pymysql.converters.escape_string(dicts[x])+'"'
-			string+=r' `%s`=%s %s'%(x,data,splitor)
+				value=self._decide_type(dicts[field])
+				string+=f' `{field}`={value} {splitor}'
 		return string[:-len(splitor)]
 	def _split_add_dict(self,dicts):
 		key=value=''
@@ -171,11 +196,22 @@ class mysql(object):
 		return self.execute(r''' insert `%s`(%s) values%s '''%(table,key,values[:-1]))
 	def update(self,where,data,table=None):
 		'''where can be str or dict'''
-		if table is None:
-			table=self.table
-		if isinstance(where,dict) : where=self._split_dict(where,'and')
+		table=self.table if table is None else table
+		where=self._split_dict(where,'and') if isinstance(where,dict) else where
 		data=self._split_dict(data)
 		return self.execute(r''' update `%s` set %s where %s'''%(table,data,where))
+	def select(self,where=None,table=None,where_splitor='and',field='*',order=None,limit=None):
+		table=self.table if table is None else table
+		query_str=f'select {field} from {table} '
+		if where:
+			where=self._split_dict(where,where_splitor) if isinstance(where,dict) else where
+			query_str+=f'where {where} '
+		if order:
+			query_str+=f'order by {order} '
+		if limit:
+			query_str+=f'limit {limit} '
+		return self.execute(query_str)
+
 class redis(object):
 	server=False
 	def __init__(self,host='127.0.0.1',db=0,port=6379,ssh_host=None,ssh_username='root',ssh_password=None):
